OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "پیام درج شده%s",
    "Important mail" : "ایمیل‌های مهم",
    "No message found yet" : "No message found yet",
    "Set up an account" : "Set up an account",
    "Unread mail" : "Unread mail",
    "Important" : "مهم",
    "Work" : "کار",
    "Personal" : "شخصی",
    "To Do" : "To Do",
    "Later" : "بعدا",
    "Mail" : "ایمیل",
    "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails." : "You are currently using {percentage} of your mailbox storage. Please make some space by deleting unneeded emails.",
    "Mails" : "ایمیل‌ها",
    "💌 A mail app for Nextcloud" : "یک برنامه نامه پستی برای Nextcloud",
    "Your session has expired. The page will be reloaded." : "Your session has expired. The page will be reloaded.",
    "Drafts are saved in:" : "Drafts are saved in:",
    "Sent messages are saved in:" : "Sent messages are saved in:",
    "Deleted messages are moved in:" : "Deleted messages are moved in:",
    "Archived messages are moved in:" : "Archived messages are moved in:",
    "Snoozed messages are moved in:" : "Snoozed messages are moved in:",
    "Junk messages are saved in:" : "Junk messages are saved in:",
    "Auto" : "خودکار",
    "Name" : "نام",
    "Mail address" : "Mail address",
    "name@example.org" : "name@example.org",
    "Please enter an email of the format name@example.com" : "Please enter an email of the format name@example.com",
    "Password" : "گذرواژه",
    "Manual" : "کتابچه راهنمای",
    "IMAP Settings" : "تنظیمات IMAP",
    "IMAP Host" : "میزبان IMAP",
    "IMAP Security" : "امنیت IMAP",
    "None" : "هیچ‌کدام",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "شروع TLS",
    "IMAP Port" : "پرت IMAP",
    "IMAP User" : "کاربر IMAP",
    "IMAP Password" : "گذرواژه IMAP",
    "SMTP Settings" : "تنظیمات SMTP",
    "SMTP Host" : "میزبان SMTP",
    "SMTP Security" : "امنیت SMTP",
    "SMTP Port" : "درگاه SMTP",
    "SMTP User" : "کاربر SMTP",
    "SMTP Password" : "رمز عبور SMTP",
    "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password." : "For the Google account to work with this app you need to enable two-factor authentication for Google and generate an app password.",
    "Connecting" : "Connecting",
    "Reconnect Google account" : "Reconnect Google account",
    "Sign in with Google" : "Sign in with Google",
    "Save" : "ذخیره",
    "Connect" : "اتصال",
    "Looking up configuration" : "Looking up configuration",
    "Checking mail host connectivity" : "Checking mail host connectivity",
    "Configuration discovery failed. Please use the manual settings" : "Configuration discovery failed. Please use the manual settings",
    "Password required" : "رمز عبور لازم است",
    "Testing authentication" : "Testing authentication",
    "Awaiting user consent" : "Awaiting user consent",
    "Account created. Please follow the pop-up instructions to link your Google account" : "Account created. Please follow the pop-up instructions to link your Google account",
    "Loading account" : "Loading account",
    "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "Account updated. Please follow the pop-up instructions to reconnect your Google account",
    "Account updated" : "Account updated",
    "IMAP server is not reachable" : "IMAP server is not reachable",
    "SMTP server is not reachable" : "SMTP server is not reachable",
    "IMAP username or password is wrong" : "IMAP username or password is wrong",
    "SMTP username or password is wrong" : "SMTP username or password is wrong",
    "IMAP connection failed" : "IMAP connection failed",
    "SMTP connection failed" : "SMTP connection failed",
    "Authorization pop-up closed" : "Authorization pop-up closed",
    "Configuration discovery temporarily not available. Please try again later." : "Configuration discovery temporarily not available. Please try again later.",
    "There was an error while setting up your account" : "There was an error while setting up your account",
    "Account settings" : "تنظیمات حساب",
    "Aliases" : "Aliases",
    "Alias to S/MIME certificate mapping" : "Alias to S/MIME certificate mapping",
    "Signature" : "امضا",
    "A signature is added to the text of new messages and replies." : "یک امضا به متن پیامها و پاسخ های جدید اضافه می شود.",
    "Writing mode" : "حالت نوشتن",
    "Preferred writing mode for new messages and replies." : "حالت نوشتن برای پیام ها و پاسخ های جدید ترجیح داده شده است.",
    "Default folders" : "Default folders",
    "The folders to use for drafts, sent messages, deleted messages, archived messages and junk messages." : "The folders to use for drafts, sent messages, deleted messages, archived messages and junk messages.",
    "Automatic trash deletion" : "Automatic trash deletion",
    "Days after which messages in Trash will automatically be deleted:" : "Days after which messages in Trash will automatically be deleted:",
    "Autoresponder" : "Autoresponder",
    "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days.",
    "Please connect to a sieve server first." : "Please connect to a sieve server first.",
    "Filters" : "Filters",
    "Mail server" : "سرور پست الکترونیکی",
    "Update alias" : "Update alias",
    "Rename alias" : "Rename alias",
    "Show update alias form" : "Show update alias form",
    "Delete alias" : "Delete alias",
    "Go back" : "برگرد",
    "Change name" : "تغییر نام",
    "Email address" : "آدرس ایمیل",
    "Add alias" : "Add alias",
    "Create alias" : "Create alias",
    "Cancel" : "لغو",
    "Mail settings" : "Mail settings",
    "Accounts" : "حساب‌ها",
    "Add mail account" : "حساب کاربری پست الکترونیکی اضافه کنید",
    "General" : "عمومی",
    "List" : "فهرست",
    "Sorting" : "مرتب سازی",
    "Newest" : "Newest",
    "Oldest" : "Oldest",
    "Use Gravatar and favicon avatars" : "از آواتارهای Gravatar و Favicon استفاده کنید",
    "Register as application for mail links" : "به عنوان برنامه برای پیوندهای نامه ثبت نام کنید",
    "Register" : "ثبت‌نام",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally.",
    "Trusted senders" : "Trusted senders",
    "Manage S/MIME certificates" : "Manage S/MIME certificates",
    "Looking for a way to encrypt your emails?" : "Looking for a way to encrypt your emails?",
    "Keyboard shortcuts" : "میان‌برهای صفحه‌کلید",
    "Compose new message" : "نوشتن پیام جدید",
    "Newer message" : "پیام جدیدتر",
    "Older message" : "پیام قدیمی تر",
    "Toggle star" : "تعویض ستاره",
    "Toggle unread" : "تغییر حالت خوانده نشده",
    "Archive" : "آرشیو",
    "Delete" : "حذف",
    "Search" : "جستجو",
    "Send" : "ارسال",
    "Refresh" : "تازه‌سازی",
    "Put my text to the bottom of a reply instead of on top of it." : "Put my text to the bottom of a reply instead of on top of it.",
    "Could not update preference" : "Could not update preference",
    "Select an alias" : "Select an alias",
    "Update Certificate" : "Update Certificate",
    "No certificate" : "No certificate",
    "Certificate updated" : "Certificate updated",
    "Could not update certificate" : "Could not update certificate",
    "{commonName} - Valid until {expiryDate}" : "{commonName} - Valid until {expiryDate}",
    "From" : "از",
    "Select account" : "حساب را انتخاب کنید",
    "To" : "به",
    "Contact or email address …" : "تماس با یا آدرس ایمیل ...",
    "Cc" : "Cc",
    "Bcc" : "Bcc",
    "Subject" : "موضوع",
    "Subject …" : "موضوع …",
    "This message came from a noreply address so your reply will probably not be read." : "این پیام از یک آدرس خیلی روشن آمده است بنابراین پاسخ شما احتمالاً خوانده نمی شود.",
    "The following recipients do not have a S/MIME certificate: {recipients}." : "The following recipients do not have a S/MIME certificate: {recipients}.",
    "The following recipients do not have a PGP key: {recipients}." : "The following recipients do not have a PGP key: {recipients}.",
    "Write message …" : "ارسال پیام ...",
    "Saving draft …" : "در حال ذخیره پیش نویس ...",
    "Error saving draft" : "Error saving draft",
    "Draft saved" : "پیش نویس ذخیره شد",
    "Save draft" : "Save draft",
    "Discard & close draft" : "Discard & close draft",
    "Enable formatting" : "قالب بندی را فعال کنید",
    "Disable formatting" : "Disable formatting",
    "Upload attachment" : "پیوست را بارگیری کنید",
    "Add attachment from Files" : "پیوست را از پرونده ها اضافه کنید",
    "Smart picker" : "Smart picker",
    "Send later" : "Send later",
    "Request a read receipt" : "Request a read receipt",
    "Sign message with S/MIME" : "Sign message with S/MIME",
    "Encrypt message with S/MIME" : "Encrypt message with S/MIME",
    "Encrypt message with Mailvelope" : "Encrypt message with Mailvelope",
    "Send now" : "Send now",
    "Tomorrow morning" : "Tomorrow morning",
    "Tomorrow afternoon" : "Tomorrow afternoon",
    "Monday morning" : "Monday morning",
    "Custom date and time" : "Custom date and time",
    "Enter a date" : "تاریخ را وارد کنید",
    "Encrypt with S/MIME and send later" : "Encrypt with S/MIME and send later",
    "Encrypt with S/MIME and send" : "Encrypt with S/MIME and send",
    "Encrypt with Mailvelope and send later" : "Encrypt with Mailvelope and send later",
    "Encrypt with Mailvelope and send" : "Encrypt with Mailvelope and send",
    "Message {id} could not be found" : "Message {id} could not be found",
    "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted." : "Sign or Encrypt with S/MIME was selected, but we don't have a certificate for the selected alias. The message will not be signed or encrypted.",
    "Any existing formatting (for example bold, italic, underline or inline images) will be removed." : "Any existing formatting (for example bold, italic, underline or inline images) will be removed.",
    "Turn off formatting" : "Turn off formatting",
    "Turn off and remove formatting" : "Turn off and remove formatting",
    "Keep formatting" : "Keep formatting",
    "Choose a file to add as attachment" : "پرونده ای را برای اضافه کردن به عنوان پیوست انتخاب کنید",
    "Choose a file to share as a link" : "Choose a file to share as a link",
    "Choose" : "انتخاب کنید",
    "_{count} attachment_::_{count} attachments_" : ["{count} attachment","{count} attachments"],
    "Expand composer" : "Expand composer",
    "Close composer" : "Close composer",
    "Untitled message" : "Untitled message",
    "Confirm" : "تائید",
    "Plain text" : "متن ساده",
    "Rich text" : "متن غنی",
    "No messages in this mailbox" : "No messages in this mailbox",
    "No messages" : "No messages",
    "Draft: " : "پیش نویس:",
    "Encrypted message" : "Encrypted message",
    "This message is unread" : "This message is unread",
    "Unfavorite" : "ناخوشایند",
    "Favorite" : "مورد‌ ‌علاقه‌",
    "Unread" : "Unread",
    "Read" : "خواندن",
    "Unimportant" : "Unimportant",
    "Mark not spam" : "Mark not spam",
    "Mark as spam" : "Mark as spam",
    "Edit tags" : "ویرایش تگ ها",
    "Snooze" : "Snooze",
    "Move thread" : "Move thread",
    "Archive thread" : "Archive thread",
    "Delete thread" : "Delete thread",
    "More actions" : "اقدامات بیشتر",
    "Back" : "بازگشت",
    "Set custom snooze" : "Set custom snooze",
    "Edit as new message" : "Edit as new message",
    "Create event" : "Create event",
    "Create task" : "وظیفه ایجاد کنید",
    "Download message" : "Download message",
    "Blind copy recipients only" : "فقط گیرندگان کپی کور",
    "No subject" : "No subject",
    "Set reminder for later today" : "Set reminder for later today",
    "Set reminder for tomorrow" : "Set reminder for tomorrow",
    "Set reminder for this weekend" : "Set reminder for this weekend",
    "Set reminder for next week" : "Set reminder for next week",
    "No trash mailbox configured" : "No trash mailbox configured",
    "Could not delete message" : "Could not delete message",
    "Could not archive message" : "Could not archive message",
    "Thread was snoozed" : "Thread was snoozed",
    "Could not snooze thread" : "Could not snooze thread",
    "Load more" : "Load more",
    "_Mark {number} read_::_Mark {number} read_" : ["Mark {number} read","Mark {number} read"],
    "_Mark {number} unread_::_Mark {number} unread_" : ["Mark {number} unread","Mark {number} unread"],
    "_Mark {number} as important_::_Mark {number} as important_" : ["Mark {number} as important","Mark {number} as important"],
    "_Mark {number} as unimportant_::_Mark {number} as unimportant_" : ["Mark {number} as unimportant","Mark {number} as unimportant"],
    "_Unfavorite {number}_::_Unfavorite {number}_" : ["Unfavorite {number}","Unfavorite {number}"],
    "_Favorite {number}_::_Favorite {number}_" : ["Favorite {number}","Favorite {number}"],
    "_Unselect {number}_::_Unselect {number}_" : ["Unselect {number}","Unselect {number}"],
    "_Move {number} thread_::_Move {number} threads_" : ["Move {number} thread","Move {number} threads"],
    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Forward {number} as attachment","Forward {number} as attachment"],
    "Report this bug" : "گزارش این اشکال",
    "All day" : "تمام روز",
    "Select calendar" : "Select calendar",
    "Description" : "شرح",
    "Create" : "ساخت",
    "Event created" : "Event created",
    "Could not create event" : "رویداد ایجاد نشد",
    "You accepted this invitation" : "You accepted this invitation",
    "You tentatively accepted this invitation" : "You tentatively accepted this invitation",
    "You declined this invitation" : "You declined this invitation",
    "You already reacted to this invitation" : "You already reacted to this invitation",
    "You have been invited to an event" : "You have been invited to an event",
    "This event was cancelled" : "This event was cancelled",
    "Save to" : "Save to",
    "Select" : "انتخاب",
    "Comment" : "نظر",
    "Accept" : "تایید",
    "Decline" : "کاهش می یابد",
    "Tentatively accept" : "Tentatively accept",
    "More options" : "More options",
    "This event is in the past." : "This event is in the past.",
    "This event was updated" : "This event was updated",
    "{attendeeName} accepted your invitation" : "{attendeeName} accepted your invitation",
    "{attendeeName} tentatively accepted your invitation" : "{attendeeName} tentatively accepted your invitation",
    "{attendeeName} declined your invitation" : "{attendeeName} declined your invitation",
    "{attendeeName} reacted to your invitation" : "{attendeeName} reacted to your invitation",
    "Failed to save your participation status" : "Failed to save your participation status",
    "domain" : "domain",
    "Remove" : "حذف",
    "email" : "ایمیل",
    "individual" : "individual",
    "Itinerary for {type} is not supported yet" : "برنامه سفر برای {نوع yet هنوز پشتیبانی نمی شود",
    "Could not open mailbox" : "صندوق پستی امکان پذیر نیست",
    "Loading messages …" : "Loading messages …",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "نمایه سازی پیام های شما این می تواند کمی برای صندوق های پستی بزرگتر کمی طولانی شود.",
    "To archive a message please configure an archive mailbox in account settings" : "To archive a message please configure an archive mailbox in account settings",
    "You are not allowed to move this message to the archive folder and/or delete this message from the current folder" : "You are not allowed to move this message to the archive folder and/or delete this message from the current folder",
    "Choose target mailbox" : "Choose target mailbox",
    "No more submailboxes in here" : "No more submailboxes in here",
    "Important info" : "Important info",
    "Other" : "دیگر",
    "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time." : "Messages will automatically be marked as important based on which messages you interacted with or marked as important. In the beginning you might have to manually change the importance to teach the system, but it will improve over time.",
    "The sender of this message has asked to be notified when you read this message." : "The sender of this message has asked to be notified when you read this message.",
    "Notify the sender" : "Notify the sender",
    "You sent a read confirmation to the sender of this message." : "You sent a read confirmation to the sender of this message.",
    "Could not send mdn" : "Could not send mdn",
    "Forward" : "فرستادن",
    "Move message" : "Move message",
    "Translate" : "ترجمه",
    "Forward message as attachment" : "Forward message as attachment",
    "View source" : "View source",
    "Download thread data for debugging" : "Download thread data for debugging",
    "Message was snoozed" : "Message was snoozed",
    "Could not snooze message" : "Could not snooze message",
    "Message body" : "Message body",
    "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!" : "Warning: The S/MIME signature of this message is unverified. The sender might be impersonating someone!",
    "Choose a folder to store the attachment in" : "لطفا پوشه ای را برای ذخیره سازی ضمیمه انتخاب کنید",
    "Import into calendar" : "وارد تقویم شوید",
    "Download attachment" : "پیوست را بارگیری کنید",
    "Save to Files" : "ذخیره در پرونده ها",
    "Unnamed" : "بی نام",
    "Embedded message" : "پیام درج شده",
    "calendar imported" : "calendar imported",
    "View fewer attachments" : "View fewer attachments",
    "Choose a folder to store the attachments in" : "پوشه ای را برای ذخیره کردن پیوست ها انتخاب کنید",
    "Save all to Files" : "ذخیره همه در پرونده ها",
    "Download Zip" : "Download Zip",
    "_View {count} more attachment_::_View {count} more attachments_" : ["View {count} more attachment","View {count} more attachments"],
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "This message is encrypted with PGP. Install Mailvelope to decrypt it.",
    "The images have been blocked to protect your privacy." : "تصاویر برای محافظت از حریم خصوصی شما مسدود شده اند.",
    "Show images" : "نمایش تصاویر",
    "Show images temporarily" : "Show images temporarily",
    "Always show images from {sender}" : "Always show images from {sender}",
    "Always show images from {domain}" : "Always show images from {domain}",
    "Message frame" : "Message frame",
    "Quoted text" : "Quoted text",
    "Move" : "انتقال",
    "Moving" : "Moving",
    "Moving thread" : "Moving thread",
    "Moving message" : "Moving message",
    "Provisioned account is disabled" : "Provisioned account is disabled",
    "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn." : "Please login using a password to enable this account. The current session is using passwordless authentication, e.g. SSO or WebAuthn.",
    "Quota" : "سهم",
    "Show only subscribed mailboxes" : "Show only subscribed mailboxes",
    "Add mailbox" : "Add mailbox",
    "Saving" : "درحال ذخیره",
    "Move up" : "Move up",
    "Move down" : "حرکت به پایین",
    "Remove account" : "حذف حساب کاربری",
    "Loading …" : "بارگذاری …",
    "Not supported by the server" : "Not supported by the server",
    "{usage} of {limit} used" : "{usage} of {limit} used",
    "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider.",
    "Remove {email}" : "Remove {email}",
    "Show all subscribed mailboxes" : "Show all subscribed mailboxes",
    "Show all mailboxes" : "Show all mailboxes",
    "Collapse mailboxes" : "Collapse mailboxes",
    "Mark all as read" : "علامت همه به عنوان خوانده‌شده",
    "Mark all messages of this mailbox as read" : "Mark all messages of this mailbox as read",
    "Add submailbox" : "Add submailbox",
    "Rename" : "تغییرنام",
    "Move mailbox" : "Move mailbox",
    "Clear cache" : "پاک‌سازی انباره",
    "Clear locally cached data, in case there are issues with synchronization." : "Clear locally cached data, in case there are issues with synchronization.",
    "Subscribed" : "Subscribed",
    "Sync in background" : "Sync in background",
    "Clear mailbox" : "Clear mailbox",
    "Delete mailbox" : "Delete mailbox",
    "All messages in mailbox will be deleted." : "All messages in mailbox will be deleted.",
    "Clear mailbox {name}" : "Clear mailbox {name}",
    "The mailbox and all messages in it will be deleted." : "The mailbox and all messages in it will be deleted.",
    "Delete mailbox {name}" : "Delete mailbox {name}",
    "An error occurred, unable to rename the mailbox." : "An error occurred, unable to rename the mailbox.",
    "_{total} message_::_{total} messages_" : ["{total} message","{total} messages"],
    "Outbox" : "Outbox",
    "New message" : "پیام جدید",
    "Error sending your message" : "خطایی در ارسال پیام شما",
    "Retry" : "تلاش دوباره",
    "Uploading attachments …" : "درحال بارگذاری پیوستها …",
    "Sending …" : "در حال ارسال ...",
    "Warning sending your message" : "Warning sending your message",
    "Send anyway" : "Send anyway",
    "Minimize composer" : "Minimize composer",
    "Edit message" : "Edit message",
    "Draft" : "Draft",
    "Reply" : "پاسخ",
    "Message saved" : "Message saved",
    "Failed to save message" : "Failed to save message",
    "Failed to save draft" : "Failed to save draft",
    "No sent mailbox configured. Please pick one in the account settings." : "No sent mailbox configured. Please pick one in the account settings.",
    "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses.",
    "Message discarded" : "Message discarded",
    "Could not discard message" : "Could not discard message",
    "Autoresponder off" : "Autoresponder off",
    "Autoresponder on" : "Autoresponder on",
    "First day" : "First day",
    "Last day (optional)" : "Last day (optional)",
    "${subject} will be replaced with the subject of the message you are responding to" : "${subject} will be replaced with the subject of the message you are responding to",
    "Message" : "پیام",
    "Oh Snap!" : "Oh Snap!",
    "Save autoresponder" : "Save autoresponder",
    "Could not open outbox" : "Could not open outbox",
    "Pending or not sent messages will show up here" : "Pending or not sent messages will show up here",
    "Message could not be sent" : "Message could not be sent",
    "Message deleted" : "Message deleted",
    "Contacts with this address" : "Contacts with this address",
    "Add to Contact" : "Add to Contact",
    "New Contact" : "New Contact",
    "Copy to clipboard" : "کپی کردن به حافظه موقت",
    "Contact name …" : "Contact name …",
    "Add" : "افزودن",
    "Copied email address to clipboard" : "Copied email address to clipboard",
    "Could not copy email address to clipboard" : "Could not copy email address to clipboard",
    "Show less" : "Show less",
    "Show more" : "Show more",
    "Search in mailbox" : "Search in mailbox",
    "Close" : "بسته",
    "Search parameters" : "Search parameters",
    "Body" : "متن",
    "Date" : "تاریخ",
    "Pick a start date" : "Pick a start date",
    "Pick an end date" : "Pick an end date",
    "Select senders" : "Select senders",
    "Select recipients" : "Select recipients",
    "Select CC recipients" : "Select CC recipients",
    "Select BCC recipients" : "Select BCC recipients",
    "Tags" : "برچسب ها",
    "Select tags" : "برچسب ها را انتخاب کنید",
    "Marked as" : "Marked as",
    "Has attachments" : "Has attachments",
    "Last 7 days" : "۷ روز گذشته",
    "Clear" : "پاک کردن",
    "Sieve Port" : "Sieve Port",
    "Custom" : "Custom",
    "Sieve User" : "Sieve User",
    "Sieve Password" : "Sieve Password",
    "Save sieve settings" : "Save sieve settings",
    "Save sieve script" : "Save sieve script",
    "The syntax seems to be incorrect:" : "The syntax seems to be incorrect:",
    "Signature …" : "امضا ...",
    "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Your signature is larger than 2 MB. This may affect the performance of your editor.",
    "Save signature" : "ذخیره امضا",
    "Place signature above quoted text" : "Place signature above quoted text",
    "Saving new tag name …" : "Saving new tag name …",
    "Set tag" : "Set tag",
    "Unset tag" : "Unset tag",
    "An error occurred, unable to rename the tag." : "An error occurred, unable to rename the tag.",
    "Add default tags" : "Add default tags",
    "Add tag" : "برچسب اضافه کنید",
    "Saving tag …" : "Saving tag …",
    "Tag name is a hidden system tag" : "Tag name is a hidden system tag",
    "Tag already exists" : "تگ از قبل وجود دارد",
    "An error occurred, unable to create the tag." : "An error occurred, unable to create the tag.",
    "No calendars with task list support" : "No calendars with task list support",
    "Task created" : "Task created",
    "Could not create task" : "Could not create task",
    "Loading thread" : "Loading thread",
    "Not found" : "پیدا نشد",
    "Summarizing thread failed." : "Summarizing thread failed.",
    "Could not load your message thread" : "Could not load your message thread",
    "The thread doesn't exist or has been deleted" : "The thread doesn't exist or has been deleted",
    "Unsubscribe" : "Unsubscribe",
    "Reply all" : "Reply all",
    "Reply to sender only" : "فقط به فرستنده پاسخ دهید",
    "Mark as unfavorite" : "Mark as unfavorite",
    "Mark as favorite" : "Mark as favorite",
    "Mark as unread" : "علامت به عنوان خوانده‌نشده",
    "Mark as read" : "علامت به عنوان خوانده‌شده",
    "Archive message" : "Archive message",
    "Delete message" : "Delete message",
    "Message source" : "Message source",
    "Unsubscribe via link" : "Unsubscribe via link",
    "Unsubscribing will stop all messages from the mailing list {sender}" : "Unsubscribing will stop all messages from the mailing list {sender}",
    "Send unsubscribe email" : "Send unsubscribe email",
    "Unsubscribe via email" : "Unsubscribe via email",
    "Encrypted & verified " : "Encrypted & verified ",
    "Signature verified" : "Signature verified",
    "Signature unverified " : "Signature unverified ",
    "This message was encrypted by the sender before it was sent." : "This message was encrypted by the sender before it was sent.",
    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent.",
    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted.",
    "Unsubscribe request sent" : "Unsubscribe request sent",
    "Could not unsubscribe from mailing list" : "Could not unsubscribe from mailing list",
    "Go to latest message" : "Go to latest message",
    "Go to newest message" : "Go to newest message",
    "{name} Assistant" : "{name} Assistant",
    "Translate message" : "Translate message",
    "Source language to translate from" : "Source language to translate from",
    "Translate from" : "Translate from",
    "Target language to translate into" : "Target language to translate into",
    "Translate to" : "Translate to",
    "Translating" : "Translating",
    "Copy translated text" : "رونوشت متن ترجمه",
    "The message could not be translated" : "The message could not be translated",
    "Translation copied to clipboard" : "Translation copied to clipboard",
    "Translation could not be copied" : "Translation could not be copied",
    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed.",
    "No senders are trusted at the moment." : "No senders are trusted at the moment.",
    "Could not remove trusted sender {sender}" : "Could not remove trusted sender {sender}",
    "(organizer)" : "(تنظیم کننده)",
    "Untitled event" : "رویداد بدون عنوان",
    "Import into {calendar}" : "{وارد {تقویم",
    "Event imported into {calendar}" : "{رویداد وارد شده به {تقویم",
    "Airplane" : "هواپیما",
    "Reservation {id}" : "رزرو {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "{پرواز} {پرواز Nr} از {depAirport} به {arrAirport}",
    "Train" : "رشته",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} از {depStation} تا {arrStation}",
    "Train from {depStation} to {arrStation}" : "آموزش از {depStation} تا {arrStation} Train",
    "Flag" : "Flag",
    "Delete filter" : "Delete filter",
    "Operator" : "Operator",
    "Actions" : "کنش‌ها",
    "New action" : "New action",
    "Priority" : "اولویت",
    "Mail app" : "برنامه پست الکترونیکی",
    "The mail app allows users to read mails on their IMAP accounts." : "برنامه نامه الکترونیکی به کاربران این امکان را می دهد تا نامه ها را در حساب های IMAP خود بخوانند.",
    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner).",
    "Account provisioning" : "Account provisioning",
    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration.",
    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration.",
    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration.",
    "There can only be one configuration per domain and only one wildcard domain configuration." : "There can only be one configuration per domain and only one wildcard domain configuration.",
    "These settings can be used in conjunction with each other." : "These settings can be used in conjunction with each other.",
    "If you only want to provision one domain for all users, use the wildcard (*)." : "If you only want to provision one domain for all users, use the wildcard (*).",
    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization.",
    "Provisioning Configurations" : "Provisioning Configurations",
    "Add new config" : "Add new config",
    "Anti Spam Service" : "Anti Spam Service",
    "You can set up an anti spam service email address here." : "You can set up an anti spam service email address here.",
    "Any email that is marked as spam will be sent to the anti spam service." : "Any email that is marked as spam will be sent to the anti spam service.",
    "Gmail integration" : "Gmail integration",
    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI.",
    "Microsoft integration" : "Microsoft integration",
    "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection." : "Microsoft allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection.",
    "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI." : "You have to register a new app in the Microsoft Azure Active Directory portal. Add the URL {url} as redirect URI.",
    "Successfully updated config for \"{domain}\"" : "Successfully updated config for \"{domain}\"",
    "Error saving config" : "Error saving config",
    "Saved config for \"{domain}\"" : "Saved config for \"{domain}\"",
    "Could not save provisioning setting" : "Could not save provisioning setting",
    "Anti Spam" : "Anti Spam",
    "Add the email address of your anti spam report service here." : "Add the email address of your anti spam report service here.",
    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\".",
    "The original message will be attached as a \"message/rfc822\" attachment." : "The original message will be attached as a \"message/rfc822\" attachment.",
    "\"Mark as Spam\" Email Address" : "\"Mark as Spam\" Email Address",
    "\"Mark Not Junk\" Email Address" : "\"Mark Not Junk\" Email Address",
    "Reset" : "بازنشاندن",
    "Successfully set up anti spam email addresses" : "Successfully set up anti spam email addresses",
    "Error saving anti spam email addresses" : "Error saving anti spam email addresses",
    "Successfully deleted anti spam reporting email" : "Successfully deleted anti spam reporting email",
    "Error deleting anti spam reporting email" : "Error deleting anti spam reporting email",
    "Client ID" : "شناسه مشتری",
    "Client secret" : "رمز مشتری",
    "Unlink" : "Unlink",
    "Google integration configured" : "Google integration configured",
    "Could not configure Google integration" : "Could not configure Google integration",
    "Google integration unlinked" : "Google integration unlinked",
    "Could not unlink Google integration" : "Could not unlink Google integration",
    "Tenant ID (optional)" : "Tenant ID (optional)",
    "Microsoft integration configured" : "Microsoft integration configured",
    "Could not configure Microsoft integration" : "Could not configure Microsoft integration",
    "Microsoft integration unlinked" : "Microsoft integration unlinked",
    "Could not unlink Microsoft integration" : "Could not unlink Microsoft integration",
    "Domain Match: {provisioningDomain}" : "Domain Match: {provisioningDomain}",
    "Email: {email}" : "ایمیل: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} on {host}: {port} (رمزگذاری {ssl))",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} on {host}: {port} (رمزگذاری s ssl))",
    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} on {host}:{port} ({ssl} encryption)",
    "Configuration for \"{provisioningDomain}\"" : "Configuration for \"{provisioningDomain}\"",
    "Provisioning domain" : "Provisioning domain",
    "Email address template" : "Email address template",
    "IMAP" : "IMAP",
    "User" : "User",
    "Host" : "میزبان",
    "Port" : "درگاه",
    "SMTP" : "SMTP",
    "Sieve" : "Sieve",
    "Enable sieve integration" : "Enable sieve integration",
    "LDAP aliases integration" : "LDAP aliases integration",
    "Enable LDAP aliases integration" : "Enable LDAP aliases integration",
    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases.",
    "LDAP attribute for aliases" : "LDAP attribute for aliases",
    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted.",
    "Save Config" : "Save Config",
    "Unprovision & Delete Config" : "Unprovision & Delete Config",
    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% and %EMAIL% will be replaced with the user's UID and email",
    "With the settings above, the app will create account settings in the following way:" : "با تنظیمات فوق ، برنامه تنظیمات حساب را به روش زیر ایجاد می کند:",
    "S/MIME certificates" : "S/MIME certificates",
    "Certificate name" : "Certificate name",
    "E-mail address" : "آدرس ایمیل",
    "Valid until" : "متعبر تا",
    "Delete certificate" : "Delete certificate",
    "No certificate imported yet" : "No certificate imported yet",
    "Import certificate" : "Import certificate",
    "Import S/MIME certificate" : "Import S/MIME certificate",
    "PKCS #12 Certificate" : "PKCS #12 Certificate",
    "PEM Certificate" : "PEM Certificate",
    "Certificate" : "گواهی",
    "Private key (optional)" : "Private key (optional)",
    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "The private key is only required if you intend to send signed and encrypted emails using this certificate.",
    "Submit" : "ارسال",
    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key.",
    "Failed to import the certificate. Please check the password." : "Failed to import the certificate. Please check the password.",
    "Certificate imported successfully" : "Certificate imported successfully",
    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase.",
    "Failed to import the certificate" : "Failed to import the certificate",
    "Account connected" : "Account connected",
    "You can close this window" : "You can close this window",
    "Connect your mail account" : "حساب ایمیل خود را وصل کنید",
    "To add a mail account, please contact your administrator." : "To add a mail account, please contact your administrator.",
    "Next week – {timeLocale}" : "Next week – {timeLocale}",
    "This weekend – {timeLocale}" : "This weekend – {timeLocale}",
    "Tomorrow – {timeLocale}" : "Tomorrow – {timeLocale}",
    "Later today – {timeLocale}" : "Later today – {timeLocale}",
    "All" : "همه",
    "Drafts" : "پیش نویس",
    "Favorites" : "علاقه مندی ها",
    "Priority inbox" : "Priority inbox",
    "All inboxes" : "همه صندوق ورودی",
    "Inbox" : "صندوق ورودی",
    "Junk" : "آشغال",
    "Sent" : "ارسال شده",
    "Trash" : "زباله ها",
    "Connect OAUTH2 account" : "Connect OAUTH2 account",
    "Error while sharing file" : "Error while sharing file",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n new message \nfrom {from}","%n new messages \nfrom {from}"],
    "Nextcloud Mail" : "ایمیل Nextclould",
    "There is already a message in progress. All unsaved changes will be lost if you continue!" : "There is already a message in progress. All unsaved changes will be lost if you continue!",
    "Discard changes" : "Discard changes",
    "Discard unsaved changes" : "Discard unsaved changes",
    "Keep editing message" : "Keep editing message",
    "Attachments were not copied. Please add them manually." : "Attachments were not copied. Please add them manually.",
    "Message sent" : "پیام ارسال شد",
    "Could not send message" : "Could not send message",
    "Could not load {tag}{name}{endtag}" : "بارگیری {برچسب} {نام} {endtag ould} بارگیری نشد",
    "There was a problem loading {tag}{name}{endtag}" : "هنگام بارگیری {tag} {name} {endtag } مشکلی رخ داد",
    "Could not load your message" : "پیام شما بارگیری نشد",
    "Could not load the desired message" : "پیام مورد نظر بارگیری نشد",
    "Could not load the message" : "بارگیری پیام امکان پذیر نیست",
    "Error loading message" : "خطا در بارگزاری پیام",
    "Forwarding to %s" : "انتقال به%s",
    "Click here if you are not automatically redirected within the next few seconds." : "اگر چند ثانیه دیگر به طور خودکار هدایت نشود ، اینجا را کلیک کنید.",
    "Redirect" : "تغییر مسیر",
    "The link leads to %s" : "پیوند منجر به%s",
    "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>.",
    "Continue to %s" : "ادامه دهید%s",
    "Unselect" : "لغو انتخاب"
},
"nplurals=2; plural=(n > 1);");
